componenttools.all_are_contiguous_components_in_same_thread
===========================================================

.. autofunction:: abjad.tools.componenttools.all_are_contiguous_components_in_same_thread.all_are_contiguous_components_in_same_thread
